/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepth;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.apache.commons.lang.math.DoubleRange;
import org.dive4elements.river.artifacts.sinfo.util.RiverInfo;

/**
 * @author Gernot Belger
 */
public final class FlowDepthCalculationResults implements Serializable {
    private static final long serialVersionUID = 1L;

    private final List<FlowDepthCalculationResult> results = new ArrayList<>();

    private final String calcModeLabel;

    private final String user;

    private final RiverInfo river;

    private final boolean useTkh;

    private final DoubleRange calcRange;

    public FlowDepthCalculationResults(final String calcModeLabel, final String user, final RiverInfo river, final DoubleRange calcRange,
            final boolean useTkh) {
        this.calcModeLabel = calcModeLabel;
        this.user = user;
        this.river = river;
        this.calcRange = calcRange;
        this.useTkh = useTkh;
    }

    public String getCalcModeLabel() {
        return this.calcModeLabel;
    }

    public String getUser() {
        return this.user;
    }

    public RiverInfo getRiver() {
        return this.river;
    }

    public DoubleRange getCalcRange() {
        return this.calcRange;
    }

    public boolean isUseTkh() {
        return this.useTkh;
    }

    void addResult(final FlowDepthCalculationResult result) {
        this.results.add(result);
    }

    public List<FlowDepthCalculationResult> getResults() {
        return Collections.unmodifiableList(this.results);
    }
}